import argparse
import re
from collections import Counter, OrderedDict
import os

def has_vowels(word):
    vowels = "AEIOUYWaeiouyw"
    return any(char in vowels for char in word) and not all(char in vowels for char in word)

def filter_vowelless_lines(input_file):
    cleaned_words = {}
    with open(input_file, 'r') as infile:
        line_count = 0
        for line in infile:
            line_count += 1
            words = line.strip().split()
            filtered_words = [word for word in words if has_vowels(word)]
            if filtered_words:
                cleaned_words[line_count] = filtered_words
    return cleaned_words

def tokenize_text(text):
    words = re.findall(r"\b(?:[A-Za-z]+(?:'\w+)?)\b", text)
    return words

def rank_words(text, cleaned_words):
    words = tokenize_text(text)
    word_counts = Counter(words)
    ranked_words = OrderedDict(sorted(word_counts.items(), key=lambda x: -x[1]))
    return ranked_words

def main():
    default_input_file = "user_raw_common.txt"
    default_output_file = "user_list_common.txt"

    parser = argparse.ArgumentParser(description="Remove lines with vowelless or vowel-only words from a text file and rank words by frequency.")
    parser.add_argument("-i", "--input_file", default=default_input_file, help=f"Name of the input file (default: {default_input_file})")
    parser.add_argument("-o", "--output_file", default=default_output_file, help=f"Name of the output file (default: {default_output_file})")

    args = parser.parse_args()

    if not os.path.exists(args.input_file):
        print(f"Error: The input file '{args.input_file}' does not exist.")
        return

    cleaned_words = filter_vowelless_lines(args.input_file)

    with open(args.input_file, 'r') as raw_file:
        raw_text = raw_file.read()

    ranked_words = rank_words(raw_text, cleaned_words)

    with open(args.output_file, 'w') as ranked_file:
        for word in ranked_words:
            ranked_file.write(f'{word}\n')

    print(f"Words Cleaned and Ranked. Output saved to '{args.output_file}'")

if __name__ == "__main__":
    main()




from plover.system.english_stenotype import *

KEYS = ('^-', 'X-', 'K-', 'P-', 'M-', 'S-', 'H-', 'L-', 'T-', 'J-', 'Q-', 'C-', 'N-', 'R-', 'D-', 'G-', 'F-', 'V-', 'B-', 'Z-', '-O', '-A', '-*', '-E', '-I')

IMPLICIT_HYPHEN_KEYS = ()
SUFFIX_KEYS = ()
NUMBERS = {}
NUMBER_KEY = None
ORTHOGRAPHY_RULES = []
ORTHOGRAPHY_WORDLIST = None
FERAL_NUMBER_KEY = False
ORTHOGRAPHY_RULES_ALIASES = {}
UNDO_STROKE_STENO = "-*"

KEYMAPS = {
 'Keyboard': {
	'^-'         : '6',
	'X-'         : 'x',
	'K-'         : 'k',
	'P-'         : 'p',
	'M-'         : 'm',
	'S-'         : 's',
	'H-'         : 'h',
	'L-'         : 'l',
	'T-'         : 't',
	'J-'         : 'j',
	'Q-'         : 'q',
	'C-'         : 'c',
	'N-'         : 'n',
	'R-'         : 'r',
	'D-'         : 'd',
	'G-'         : 'g',
	'F-'         : 'f',
	'V-'         : 'v',
	'B-'         : 'b',
	'Z-'         : 'z',
	'-O'         : 'o',
	'-A'         : 'a',
	'-*'         : 'u',
	'-E'         : 'e',
	'-I'         : 'i',
        'arpeggiate': 'space',
        # Suppress adjacent keys to prevent miss-strokes.
        'no-op'     : ''
    }
}

DICTIONARIES_ROOT = 'asset:stenobee:assets'

DEFAULT_DICTIONARIES = (
    'StenoBee-Core.json',
    'StenoBee-Common.json',
    'StenoBee-Proper-Nouns.json',
    'StenoBee-Numbers.py',
    'StenoBee-Alt_Ergo_Numbers.json',
    'StenoBee-Symbols&Spelling.json',
    'StenoBeeNiche-Pokemon-[KPMN].json',
    'StenoBeeNiche-Emoji-[MJ].json',
    'StenoBeeNiche-Minecraft-[MTCNRF].json',
    'StenoBeeNiche-Mineral-[MLNR].json',
    'StenoBeeNiche-Chemistry-[MSHTCR].json',
    'StenoBeeNiche-ModeSetSpace-[PMSTCD].json',
)









